<?php

/*
 * 送信時にflagを送信させる
 *
 *
 */

//関数
require("../lib/pdo_search.php");
require ("../lib/search_str.php");

function getquery($name) {
		$select = "SELECT * ";
		$from =  "FROM Version0_db ";

		// WHERE句
		$name = search_str($name);
		for($i=1;$i<count($name)+1;$i++) {


			if($i == 1){

				$where = " WHERE book_name LIKE  \"%". $name[$i-1] ."%\" ";
			} else {
				$where .= " AND book_name LIKE  \"%". $name[$i-1] ."%\" ";

			}	

		} 		

			$query = $select.$from.$where;
			return $query;
		}

//本体



if(isset($_GET['switch'] )) {
	
	//クエリーの作成
	
	if(isset($_GET['name'])){	
		

		$name = $_GET['name'];
		$query = getquery($name);	
	} else {  //一覧表示

			$query = "SELECT *  FROM Version0_db ";
	}

	$array = pdo_search($query);


	if($array === "none") {
		$flag = "false";
	}else if(isset($array)) {

		$flag = "true";
		$count = count($array);
	} else {
		$flag = "false";

	}


} else { //未送信時
	$name = NULL ;
	$flag = "none";
}	



require("../lib/smarty.php");

if($flag == "true") {
	$smarty->assign("book",$array);
	$smarty->assign("count",$count);

}

if(isset($name)) {
	if($name[0]   == "") {               
	$smarty->assign("all","all");	
}
}
$smarty->assign("flag",$flag);
$smarty->assign("title","本の検索"); //headerのtitle

$smarty->display("book_search.tpl");



